@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v0.7.3");
+use version; our $VERSION = version->declare("v0.7.4");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -162,7 +162,7 @@ Minilla sets bugtracker as github issues by default. But if you want to use RT,
     [no_index]
     directory=['t', 'xt', 'tools']
 
-Minilla sets META.json's no_index as C<< directory => ['t', 'xt', 'inc', 'share', 'eg', 'examples', 'author'] >>
+Minilla sets META.json's no_index as C<< directory => ['t', 'xt', 'inc', 'share', 'eg', 'examples', 'author', 'builder'] >>
 by default. But if you want to change them, you can set this section variable. If this section is set,
 specified variables are only used, in fact default settings are not merged.
 
@@ -206,7 +206,7 @@ Specify the PL files.
 Specify a custom Module::Build subclass.
 
     [build]
-    build_class = builder::MyBuilder
+    build_class = "builder::MyBuilder"
 
 =item XSUtil.needs_compiler_c99
 
